package beilv.carinformation.service;

import beilv.carinformation.domain.CarInformation;

import java.util.List;

/**
 * 卡种信息Service接口
 *
 * @author ruoyi
 * @date 2025-01-02
 */
public interface ICarInformationService {
    /**
     * 查询卡种信息
     *
     * @param id 卡种信息主键
     * @return 卡种信息
     */
    public CarInformation selectCarInformationById(Long id);

    /**
     * 查询卡种信息列表
     *
     * @param carInformation 卡种信息
     * @return 卡种信息集合
     */
    public List<CarInformation> selectCarInformationList(CarInformation carInformation);

    /**
     * 新增卡种信息
     *
     * @param carInformation 卡种信息
     * @return 结果
     */
    public int insertCarInformation(CarInformation carInformation);

    /**
     * 修改卡种信息
     *
     * @param carInformation 卡种信息
     * @return 结果
     */
    public int updateCarInformation(CarInformation carInformation);

    /**
     * 批量删除卡种信息
     *
     * @param ids 需要删除的卡种信息主键集合
     * @return 结果
     */
    public int deleteCarInformationByIds(String ids);

    /**
     * 删除卡种信息信息
     *
     * @param id 卡种信息主键
     * @return 结果
     */
    public int deleteCarInformationById(Long id);
}
